@@ -460,6 +460,7 @@ class DuneQuery:
                 "visualizations",
                 "forked_query",
                 "user",
+                "team",
                 "query_favorite_count_all",
                 "favorite_queries",
             }
@@ -507,6 +508,7 @@ class DuneQuery:
                   ...QueryVisualizations
                   ...QueryForked
                   ...QueryUsers
+                  ...QueryTeams
                   ...QueryFavorites
                 }
                 fragment BaseQuery on queries {
@@ -540,18 +542,38 @@ class DuneQuery:
                     user {
                       name
                     }
+                    team {
+                     handle
+                    }
                   }
                 }
                 fragment QueryUsers on queries {
                   user {
                     ...User
                   }
+                  team {
+                    id
+                    name
+                    handle
+                    profile_image_url
+                  }
                 }
                 fragment User on users {
                   id
                   name
                   profile_image_url
                 }
+                fragment QueryTeams on queries {
+                  team {
+                    ...Team
+                  }
+                }
+                fragment Team on teams {
+                  id
+                  name
+                  handle
+                  profile_image_url
+                }
                 fragment QueryFavorites on queries {
                   query_favorite_count_all @include(if: $favs_all_time) {
                     favorite_count
@@ -576,7 +598,7 @@ class DuneQuery:
         """Returns json data for a post of type FindResultDataByResult"""
         query = """
         query FindResultDataByJob($job_id: uuid!) {
-          query_results(where: {job_id: {_eq: $job_id}, error: {_is_null: true}}) {
+          query_results(where: {job_id: {_eq: $job_id}}) {
             id
             job_id
             runtime
